==> owncloud-8.2.2-2-any.pkg.tar.xz: usr/share/webapps/owncloud/core/l10n/de_AT.js <==
OC.L10N.register(
    "core",
    {
    "Sunday" : "Sonntag",
    "Monday" : "Montag",
    "Tuesday" : "Dienstag",
    "Wednesday" : "Mittwoch",
    "Thursday" : "Donnerstag",
    "Friday" : "Freitag",
    "Saturday" : "Samstag",
    "Sun." : "So",
    "Mon." : "Mo",
    "Tue." : "Di",
    "Wed." : "Mi",
    "Thu." : "Do",
    "Fri." : "Fr",
    "Sat." : "Sa",
    "January" : "Januar",
    "February" : "Februar",
    "March" : "März",
    "April" : "April",
    "May" : "Mai",
    "June" : "Juni",
    "July" : "Juli",
    "August" : "August",
    "September" : "September",
    "October" : "Oktober",
    "November" : "November",
    "December" : "Dezember",
    "Jan." : "Jan.",
    "Feb." : "Feb.",
    "Mar." : "Mär.",
    "Apr." : "Apr.",
    "May." : "Mai",
    "Jun." : "Jun.",
    "Jul." : "Jul.",
    "Aug." : "Aug.",
    "Sep." : "Sep.",
    "Oct." : "Okt.",
    "Nov." : "Nov.",
    "Dec." : "Dez.",
    "Settings" : "Einstellungen",
    "seconds ago" : "Sekunden zuvor",
    "No" : "Nein",
    "Yes" : "Ja",
    "Cancel" : "Abbrechen",
    "Continue" : "Weiter",
    "Error" : "Fehler",
    "Share link" : "Link teilen",
    "Password" : "Passwort",
    "Send" : "Senden",
    "group" : "Gruppe",
    "Unshare" : "Teilung zurücknehmen",
    "can share" : "Kann teilen",
    "can edit" : "kann bearbeiten",
    "Share" : "Freigeben",
    "Delete" : "Löschen",
    "Add" : "Hinzufügen",
    "Personal" : "Persönlich",
    "Help" : "Hilfe",
    "Username" : "Benutzername"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-9.0.2-2-any.pkg.tar.xz: usr/share/webapps/owncloud/core/l10n/de_AT.js <==
OC.L10N.register(
    "core",
    {
    "Sunday" : "Sonntag",
    "Monday" : "Montag",
    "Tuesday" : "Dienstag",
    "Wednesday" : "Mittwoch",
    "Thursday" : "Donnerstag",
    "Friday" : "Freitag",
    "Saturday" : "Samstag",
    "Sun." : "So",
    "Mon." : "Mo",
    "Tue." : "Di",
    "Wed." : "Mi",
    "Thu." : "Do",
    "Fri." : "Fr",
    "Sat." : "Sa",
    "January" : "Januar",
    "February" : "Februar",
    "March" : "März",
    "April" : "April",
    "May" : "Mai",
    "June" : "Juni",
    "July" : "Juli",
    "August" : "August",
    "September" : "September",
    "October" : "Oktober",
    "November" : "November",
    "December" : "Dezember",
    "Jan." : "Jan.",
    "Feb." : "Feb.",
    "Mar." : "Mär.",
    "Apr." : "Apr.",
    "May." : "Mai",
    "Jun." : "Jun.",
    "Jul." : "Jul.",
    "Aug." : "Aug.",
    "Sep." : "Sep.",
    "Oct." : "Okt.",
    "Nov." : "Nov.",
    "Dec." : "Dez.",
    "Settings" : "Einstellungen",
    "seconds ago" : "Sekunden zuvor",
    "No" : "Nein",
    "Yes" : "Ja",
    "Cancel" : "Abbrechen",
    "Continue" : "Weiter",
    "Error" : "Fehler",
    "Share link" : "Link teilen",
    "Password" : "Passwort",
    "Send" : "Senden",
    "group" : "Gruppe",
    "Unshare" : "Teilung zurücknehmen",
    "can share" : "Kann teilen",
    "can edit" : "kann bearbeiten",
    "Share" : "Freigeben",
    "Delete" : "Löschen",
    "Add" : "Hinzufügen",
    "Personal" : "Persönlich",
    "Help" : "Hilfe",
    "Username" : "Benutzername",
    "Fri." : "Fr",
    "Mon." : "Mo",
    "Sat." : "Sa"
},
"nplurals=2; plural=(n != 1);");
